abclinuxu.cz AbcLinuxu.cz itbiz.cz ITBiz.cz HDmag.cz HDmag.cz abcprace.cz AbcPráce.cz
AbcLinuxu hledá autory!
Inzerujte na AbcPráce.cz od 950 Kč
Rozšířené hledání
×

    dnes 13:00 | Bezpečnostní upozornění
    Nové vydání zlib opravuje několik problémů při kompresi a dekompresi dat, přetečení bufferů, čtení mimo vyhrazenou paměť, únik neinicializovaných dat. Zvlášť významné jsou chyby v inflateGetDictionary(), inflateSync() a gzwrite(), které mohou způsobit poškození paměti. Vysoká relevance - zlib používá řada systémových i aplikačních komponent.
    vencour | Komentářů: 0
    dnes 12:25 | Bezpečnostní upozornění
    Digicert hlásí neoprávněné čtení archivních zákaznických údajů. Došlo k němu po migraci z února 2025, po níž se interní systém, dříve dostupný jen přes VPN, stal přístupným z internetu. Chyba v oprávněních umožnila nově vytvořeným účtům číst archivní záznamy. K přístupu k datům mělo dojít mezi 27. červnem a 2. červencem 2026. DigiCert neoprávněné čtení potvrdil až 19. října 2026. Problém zpočátku vyhodnotil jako tvorbu účtů, ne jako … více »
    vencour | Komentářů: 0
    dnes 04:44 | Pozvánky

    O víkendu probíhá na FIT VUT v Brně konference OpenAlt 2026 o otevřeném softwaru a datech, IT bezpečnosti, DIY a IoT. Na programu je spousta zajímavých přednášek. Pokud jste v Brně, stavte se. Vstup zdarma. Přednášky lze sledovat i online na VHSky a YouTube.

    Ladislav Hagara | Komentářů: 0
    dnes 02:11 | IT novinky

    Qualcomm uzavřel víceletou dohodu se SpaceX. Bude dodávat rádiové technologie, baseband jednotky a software pro plánovanou pozemní 5G síť Starlink Mobile. Výstavba má zahrnovat desítky tisíc základnových stanic v USA. Zahájení nasazování se očekává v roce 2027. Qualcomm dohodu označuje za svůj dosud největší 5G kontrakt.

    vencour | Komentářů: 0
    dnes 02:00 | IT novinky

    Google rozšířil Cloud Vulnerability Reward Program. Nově nabízí odměnu až 250 tisíc dolarů za vysoce závažné architektonické bezpečnostní chyby označované jako Root-in-Cloud.

    vencour | Komentářů: 0
    včera 12:22 | IT novinky

    V březnu byla oznámena spolupráce GrapheneOS s Motorolou. Nejnovější vlajka Motorola Signature 27 je první Motorola s oficiální podporou GrapheneOS. GrapheneOS (Wikpedie) je varianta Androidu zaměřující se na bezpečnost a soukromí.

    Ladislav Hagara | Komentářů: 0
    včera 04:55 | Nová verze

    Omarchy (Wikipedie) je linuxová distribuce s dlaždicovým správcem oken Hyprland. Založena je na Arch Linuxu. Vydána byla v nové verzi 4.5.0. Nově také pro Apple Silicon, konkrétně pro M1/M2/M3/Neo MacBooky.

    Ladislav Hagara | Komentářů: 3
    včera 03:22 | Nová verze

    Byla vydána nová stabilní verze 8.3 webového prohlížeče Vivaldi (Wikipedie). Postavena je na Chromiu 156 s bezpečnostními opravami z Chromia 157. Přehled novinek i s náhledy v příspěvku na blogu.

    Ladislav Hagara | Komentářů: 0
    5.11. 19:53 | Bezpečnostní upozornění
    V Xenu objevena zranitelnost. Chyba v mechanismu grant copy umožňuje škodlivému virtuálnímu stroji číst a přepisovat libovolnou paměť jiných VM včetně privilegované domény Dom0. Dotčené verze jsou Xen 4.6 a novější. V upstreamu jsou dostupné patche pro Xen 4.17 až 4.19 a vývojovou větev. Pro starší nepodporované verze 4.6–4.16 nejsou v XSA-523 přiloženy opravy.
    vencour | Komentářů: 2
    5.11. 16:55 | Nová verze

    Multimediální přehrávač mpv byl vydán ve verzi 0.42.0. Jde o větší balík změn po bezmála roce. Mimo jiné se lépe integruje s Waylandem nebo rozšiřuje podporu DVD/Blu-ray, např. umožňuje přehrávat rovnou obrazy médií (soubory iso).

    ʚĭɞ 🍉 | Komentářů: 0
    Které desktopové prostředí na Linuxu používáte?
     (9%)
     (7%)
     (4%)
     (21%)
     (30%)
     (9%)
     (5%)
     (2%)
     (14%)
     (20%)
    Celkem 2999 hlasů
     Komentářů: 35, poslední včera 23:27
    Rozcestník

    Dotaz: Bash: read a doplňování

    David Watzke avatar 15.3.2006 05:49 David Watzke | skóre: 74 | blog: Blog... | Praha
    Bash: read a doplňování
    Přečteno: 775×
    Ahoj. Existuje něco jako read, co doplňuje cesty? Občas bych potřeboval do skriptů - je nuda psát to bez doplňování, navíc to zdržuje a není to efektivní :-) Dopodá to potom takhle:
    $ read i
    /et     po      pa      k
    “Being honest may not get you a lot of friends but it’ll always get you the right ones” ―John Lennon

    Odpovědi

    15.3.2006 08:17 Michal Karas | skóre: 45 | blog: /dev/random
    Rozbalit Rozbalit vše Re: Bash: read a doplňování
    Myslíš něco jako ve Vimu CTRL-X CTRL-F?
    15.3.2006 08:46 Michal Karas | skóre: 45 | blog: /dev/random
    Rozbalit Rozbalit vše Re: Bash: read a doplňování
    Jo aha, teď jsem si to přečetl ještě jednou a konečně mi došlo, co vlastně chceš. Tak nic.
    15.3.2006 10:04 Hynek (Pichi) Vychodil | skóre: 43 | blog: Pichi | Brno
    Rozbalit Rozbalit vše Re: Bash: read a doplňování
    RTFM
           read [-ers] [-u fd] [-t timeout] [-a aname] [-p prompt] [-n nchars] [-d
           delim] [name ...]
                  One line is read from the  standard  input,  or  from  the  file
                  descriptor  fd supplied as an argument to the -u option, and the
                  first word is assigned to the first name, the second word to the
                  second  name, and so on, with leftover words and their interven-
                  ing separators assigned to the last name.  If  there  are  fewer
                  words read from the input stream than names, the remaining names
                  are assigned empty values.  The characters in IFS  are  used  to
                  split  the  line into words.  The backslash character (\) may be
                  used to remove any special meaning for the next  character  read
                  and  for line continuation.  Options, if supplied, have the fol-
                  lowing meanings:
                  -a aname
                         The words are assigned to sequential indices of the array
                         variable aname, starting at 0.  aname is unset before any
                         new  values  are  assigned.   Other  name  arguments  are
                         ignored.
                  -d delim
                         The  first  character  of  delim is used to terminate the
                         input line, rather than newline.
                  -e     If the standard input is coming from a terminal, readline
                         (see READLINE above) is used to obtain the line.
                  -n nchars
                         read  returns after reading nchars characters rather than
                         waiting for a complete line of input.
                  -p prompt
                         Display prompt on standard error, without a trailing new-
                         line, before attempting to read any input.  The prompt is
                         displayed only if input is coming from a terminal.
                  -r     Backslash does not act as an escape character.  The back-
                         slash  is considered to be part of the line.  In particu-
                         lar, a backslash-newline pair may not be used as  a  line
                         continuation.
                  -s     Silent mode.  If input is coming from a terminal, charac-
                         ters are not echoed.
                  -t timeout
                         Cause read to time out and return failure if  a  complete
                         line  of  input is not read within timeout seconds.  This
                         option has no effect if read is not  reading  input  from
                         the terminal or a pipe.
                  -u fd  Read input from file descriptor fd.
    
                  If no names are supplied, the line read is assigned to the vari-
                  able REPLY.  The return code  is  zero,  unless  end-of-file  is
                  encountered,  read  times  out, or an invalid file descriptor is
                  supplied as the argument to -u.
    
    XML je zbytečný, pomalý, nešikovný balast, znovu vynalézané kolo a ještě ke všemu šišaté, těžké a kýčovitě pomalované.
    15.3.2006 10:09 Hynek (Pichi) Vychodil | skóre: 43 | blog: Pichi | Brno
    Rozbalit Rozbalit vše Re: Bash: read a doplňování
    Tak mám pocit, že poslední dobou je moje nejčastější odpověď RTFM, ale co mám dělat, když lidi kurva zatvrzele odmítají Read This Fuckin Manual!
    XML je zbytečný, pomalý, nešikovný balast, znovu vynalézané kolo a ještě ke všemu šišaté, těžké a kýčovitě pomalované.
    15.3.2006 11:29 barney
    Rozbalit Rozbalit vše Re: Bash: read a doplňování
    skúsiť povedať ktorý manuál ? :-)
    man bash
    /^ *read \[
    
    15.3.2006 11:34 hm
    Rozbalit Rozbalit vše Re: Bash: read a doplňování
    help read
    David Watzke avatar 15.3.2006 14:05 David Watzke | skóre: 74 | blog: Blog... | Praha
    Rozbalit Rozbalit vše Re: Bash: read a doplňování
    Oops... četl jsem to moc letmo :-( Díky.
    read -e variable
    je řešení.
    “Being honest may not get you a lot of friends but it’ll always get you the right ones” ―John Lennon
    15.3.2006 14:14 Hynek (Pichi) Vychodil | skóre: 43 | blog: Pichi | Brno
    Rozbalit Rozbalit vše Re: Bash: read a doplňování
    I ty Brute :-(
    XML je zbytečný, pomalý, nešikovný balast, znovu vynalézané kolo a ještě ke všemu šišaté, těžké a kýčovitě pomalované.
    David Watzke avatar 6.5.2006 08:21 David Watzke | skóre: 74 | blog: Blog... | Praha
    Rozbalit Rozbalit vše Re: Bash: read a doplňování
    Další dotaz ;-) Existuje totéž i pro Perl? Hodilo by se mi doplňování cesty, ale bojím se, že to nejde...
    “Being honest may not get you a lot of friends but it’ll always get you the right ones” ―John Lennon

    Založit nové vlákno • Nahoru

    Tiskni Sdílej: Linkuj Jaggni to Vybrali.sme.sk Google Del.icio.us Facebook

    ISSN 1214-1267   www.czech-server.cz
    © 1999-2015 Nitemedia s. r. o. Všechna práva vyhrazena.